# Changelog

## [0.2.1](https://github.com/zachrobo1/zap-ai/compare/v0.2.0...v0.2.1) (2026-01-08)


### Features

* add context support for dynamic prompts ([#4](https://github.com/zachrobo1/zap-ai/issues/4)) ([7751951](https://github.com/zachrobo1/zap-ai/commit/775195151644c681a982c58bae956c706d4318f5))
* add GitHub releases with changelog tracking ([#3](https://github.com/zachrobo1/zap-ai/issues/3)) ([d02ae20](https://github.com/zachrobo1/zap-ai/commit/d02ae20972f7e174d22c100c120fcfc64d9f2e1a))

## [0.2.0](https://github.com/zachrobo1/zap-ai/compare/v0.1.0...v0.2.0) (2025-01-04)

### Features

* add tracing module with Langfuse integration ([#2](https://github.com/zachrobo1/zap-ai/pull/2))
* add Temporal integration tests to CI ([#1](https://github.com/zachrobo1/zap-ai/pull/1))

## 0.1.0 (2024-12-29)

### Features

* Library MVP - initial release with core Zap functionality
* Temporal-based agent orchestration
* MCP tool integration via FastMCP
* LiteLLM provider abstraction
